==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/Input/opus/translations/opus_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="49"/>
        <source>Opus Plugin</source>
        <translation>Модуль Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="52"/>
        <source>Ogg Opus Files</source>
        <translation>Файлы Ogg Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="126"/>
        <source>About Opus Audio Plugin</source>
        <translation>Об аудио-модуле Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="127"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>Модуль Opus для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="128"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>Length</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Sample rate</source>
        <translation>Дискретизация</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="57"/>
        <source>Channels</source>
        <translation>Каналов</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>Bitrate</source>
        <translation>Битовая частота</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>kbps</source>
        <translation>Кб/с</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>File size</source>
        <translation>Размер файла</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>KB</source>
        <translation>КБ</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/opus/translations/opus_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="44"/>
        <source>Opus Plugin</source>
        <translation>Модуль Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="47"/>
        <source>Ogg Opus Files</source>
        <translation>Файлы Ogg Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="121"/>
        <source>About Opus Audio Plugin</source>
        <translation>Об аудио-модуле Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="122"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>Модуль Opus для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="123"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>Length</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Sample rate</source>
        <translation>Дискретизация</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="57"/>
        <source>Channels</source>
        <translation>Каналов</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>Bitrate</source>
        <translation>Битовая частота</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>kbps</source>
        <translation>кбит/с</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>File size</source>
        <translation>Размер файла</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>KB</source>
        <translation>КБ</translation>
    </message>
</context>
</TS>
